@@ -1,4 +1,5 @@
-# -*- coding: utf-8 -*-
+#!/usr/bin/python
+# coding: utf8
 
 from base import Base
 
@@ -16,26 +17,28 @@ class Osm(Base):
         self.params['addressdetails'] = 1
         self.params['q'] = location
 
+    @property
     def lat(self):
         return self.safe_coord('lat')
 
+    @property
     def lng(self):
         return self.safe_coord('lon')
 
-    def address(self):
-        return self.safe_format('display_name')
-
+    @property
     def quality(self):
         return self.safe_format('type')
 
+    @property
     def postal(self):
         postal = self.safe_format('address-postcode')
         if postal:
             return postal
-        else:
+        elif self.address:
             # Using Regular Expressions to get Postal Code from Address
-            return self.safe_postal(self.address())
+            return self.safe_postal(self.address)
 
+    @property
     def bbox(self):
         south = self.json.get('boundingbox-0')
         west = self.json.get('boundingbox-2')
@@ -43,11 +46,30 @@ class Osm(Base):
         east = self.json.get('boundingbox-3')
         return self.safe_bbox(south, west, north, east)
 
+    @property
+    def address(self):
+        return self.safe_format('display_name')
+
+    @property
+    def street_number(self):
+        return self.safe_format('address-house_number')
+
+    @property
+    def route(self):
+        return self.safe_format('address-road')
+
+    @property
+    def neighborhood(self):
+        return self.safe_format('address-suburb')
+
+    @property
     def locality(self):
         return self.safe_format('address-city')
 
+    @property
     def state(self):
         return self.safe_format('address-state')
 
+    @property
     def country(self):
         return self.safe_format('address-country')
